@@ -1,4 +1,4 @@
-// $Id: BinBox.h,v 1.11 2000/12/11 12:21:47 zeller Exp $
+// $Id$
 // Bin boxes
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -48,7 +48,7 @@ protected:
     BinBox(const BinBox& box): HatBox(box)
     {}
 
-    void dump(ostream& s) const;
+    void dump(std::ostream& s) const;
 
 public:
     BinBox(Box *box, const char *t = "BinBox"): HatBox(box, t)
