@@ -1,4 +1,4 @@
-// $Id: BoxRegion.h,v 1.12 1999/08/19 11:27:08 andreas Exp $  -*- C++ -*-
+// $Id$  -*- C++ -*-
 // BoxRegion class
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -36,7 +36,7 @@
 
 // A BoxRegion is a rectangular area which has an ORIGIN and a SPACE.
 
-#include <iostream.h>
+#include <iostream>
 #include "misc.h"
 #include "BoxPoint.h"
 #include "BoxSize.h"
@@ -108,7 +108,7 @@ public:
     }
 
     // Debugging
-    friend ostream& operator << (ostream& s, const BoxRegion& r);
+    friend std::ostream& operator << (std::ostream& s, const BoxRegion& r);
 };
 
 // Check if P is contained in R
