@@ -45,12 +45,27 @@
 #include "GDBAgent.h"
 #include "StringA.h"
 
-// Breakpoint type
+// Breakpoint type, respectively:
+//  Breakpoint
+//  Watchpoint
+//  Tracepoint (as in GDB)
+//  Actionpoint (`when' in DBX, action in Perl)
+#define BREAKPOINT_TABLE     \
+X(BREAKPOINT,"Breakpoint"),  \
+X(WATCHPOINT,"Watchpoint"),  \
+X(TRACEPOINT,"Tracepoint"),  \
+X(ACTIONPOINT,"Actionpoint")
+
+#define BREAKPOINT_TABLE_NOC \
+X(BREAKPOINT,"Breakpoint")   \
+X(WATCHPOINT,"Watchpoint")   \
+X(TRACEPOINT,"Tracepoint")   \
+X(ACTIONPOINT,"Actionpoint")
+
 enum BPType {
-    BREAKPOINT,			// Breakpoint
-    WATCHPOINT,			// Watchpoint
-    TRACEPOINT,			// Tracepoint (as in GDB)
-    ACTIONPOINT 		// Actionpoint (`when' in DBX, action in Perl)
+#define X(a,b) a
+    BREAKPOINT_TABLE
+#undef X
 };
 
 // What to do when breakpoint is reached
@@ -87,41 +102,13 @@ class BreakPoint {
     Widget  mycode_glyph;	// Associated glyph in code
 
 private:
-    BreakPoint(const BreakPoint& b)
-	: mynumber(b.mynumber),
-	  mytype(b.mytype),
-	  mydispo(b.mydispo),
-	  myenabled(b.myenabled),
-	  myfile_name(b.myfile_name),
-	  myline_nr(b.myline_nr),
-	  myaddress(b.myaddress),
-	  myfunc(b.myfunc),
-	  myexpr(b.myexpr),
-	  myinfos(b.myinfos),
-	  myignore_count(b.myignore_count),
-	  mycondition(b.mycondition),
-	  mycommands(b.mycommands),
-	  myarg(b.myarg),
-	  mywatch_mode(b.mywatch_mode),
-	  myenabled_changed(b.myenabled_changed),
-	  myfile_changed(b.myfile_changed),
-	  myposition_changed(b.myposition_changed),
-	  myaddress_changed(b.myaddress_changed),
-	  myselected(b.myselected),
-	  mysource_glyph(b.mysource_glyph),
-	  mycode_glyph(b.mycode_glyph)
-    {
-	assert(0);
-    }
-    BreakPoint& operator = (const BreakPoint&)
-    {
-	assert(0); return *this;
-    }
+    BreakPoint(const BreakPoint&);
+    BreakPoint& operator = (const BreakPoint&);
 
 protected:
     // Helpers
-    static string false_value();
-    static string and_op();
+    static const string& false_value();
+    static const string& and_op();
     static bool is_false(const string& cond);
 
     void process_gdb(string& info_output);
@@ -152,7 +139,7 @@ public:
 
     // Breakpoint type.
     BPType type() const { return mytype; }
-    string title() const;
+    const string& title() const;
 
     // What to do when breakpoint is reached.
     BPDispo dispo() const { return mydispo; }
