@@ -63,14 +63,11 @@ protected:
     bool matches(const VSLNode& node) const
     {
 	return VSLNode::matches(node) &&
-		*_box == *(((ConstNode *)&node)->_box); // dirty trick
+		*_box == *(((const ConstNode *)&node)->_box); // dirty trick
     }
 
 private:
-    ConstNode& operator = (const ConstNode&)
-    {
-	assert(0); return *this;
-    }
+    ConstNode& operator = (const ConstNode&);
 
 public:
     // Constructor
