@@ -67,14 +67,11 @@ protected:
     {
 	return matchesAll ||
 	    (CallNode::matches(node) &&
-		_deflist == ((DefCallNode *)&node)->_deflist); // dirty trick
+		_deflist == ((const DefCallNode *)&node)->_deflist); // dirty trick
     }
 
 private:
-    DefCallNode& operator = (const DefCallNode&)
-    {
-	assert(0); return *this;
-    }
+    DefCallNode& operator = (const DefCallNode&);
 
 public:
     // Copy
