@@ -61,7 +61,7 @@ protected:
 
     bool matches (const Box &b, const Box * = 0) const
     {
-	return Box::matches(b) && *_box == *(((HatBox *)&b)->_box);
+	return Box::matches(b) && *_box == *(((const HatBox *)&b)->_box);
     }
 
     const TagBox *findTag(const BoxPoint& p) const
@@ -70,7 +70,7 @@ protected:
     }
 
 private:
-    HatBox& operator = (const HatBox&) { assert(0); return *this; }
+    HatBox& operator = (const HatBox&);
 
 public:
     HatBox(Box *box, const char *t = "HatBox"): 
