@@ -61,12 +61,12 @@ protected:
     bool matches(const VSLNode& node) const
     {
 	return VSLNode::matches(node) &&
-	    *_head == *(((ListNode *)&node)->_head) && 
-	    *_tail == *(((ListNode *)&node)->_tail);    // dirty trick
+	    *_head == *(((const ListNode *)&node)->_head) && 
+	    *_tail == *(((const ListNode *)&node)->_tail);    // dirty trick
     }
 
 private:
-    ListNode& operator = (const ListNode&) { assert(0); return *this; }
+    ListNode& operator = (const ListNode&);
 
 public:
     ListNode(VSLNode *hd, VSLNode *tl, const char *type = "ListNode");
@@ -105,10 +105,10 @@ public:
     // Other tree functions
     void compilePatterns(VSLDef *cdef) const;
     void uncompilePatterns(VSLDef *cdef) const;
-    int resolveName(VSLDef *cdef, VSLNode **node, string& name, unsigned id);
+    int resolveName(VSLDef *cdef, VSLNode **node, const string& name, unsigned id);
     int _resolveNames(VSLDef *cdef, unsigned base);
     void rebind(const class VSLLib *);
-    string firstName() const;
+    const string& firstName() const;
 
     // Append to list
     int append(VSLNode *node);
@@ -118,7 +118,9 @@ public:
     void _dumpTree(std::ostream& s) const;
 
     // Properties
-    bool isConst() const;
+    bool isConst() const {
+      return _head->isConst() && _tail->isConst();
+    }
     bool isListNode() const { return true; }
     bool isStraight() const;
 
