@@ -1,4 +1,4 @@
-// $Id: MatchBox.h,v 1.12 2000/12/11 12:21:47 zeller Exp $ 
+// $Id$ 
 // Matching boxes (for pattern matching)
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -66,7 +66,7 @@ protected:
 	_data(box._data)
     {}
 
-    void dump(ostream& s) const;
+    void dump(std::ostream& s) const;
 
     // Call matchCallback if matches
     bool matches (const Box &b, const Box *callbackArg = 0) const;
