@@ -43,18 +43,10 @@ private:
     StringArray _theme_list;
 
     // Assignment
-    ThemedVSLLib& operator=(const ThemedVSLLib&)
-    {
-	assert(0);
-	return *this;
-    }
+    ThemedVSLLib& operator=(const ThemedVSLLib&);
 
     // Copy constructor
-    ThemedVSLLib(const ThemedVSLLib& lib)
-	: VSLLib(lib), _original_lib(0), _optimizeMode(0), _theme_list()
-    {
-	assert(0);
-    }
+    ThemedVSLLib(const ThemedVSLLib&);
 
 public:
     // Build
