@@ -40,17 +40,9 @@
 class VSLArgList {
     ListBox *_list;
 
-    VSLArgList& operator=(const VSLArgList&)
-    {
-	assert(0);
-	return *this;
-    }
+    VSLArgList& operator=(const VSLArgList&);
 
-    VSLArgList(const VSLArgList&)
-	: _list(0)
-    {
-	assert(0);
-    }
+    VSLArgList(const VSLArgList&);
 
 public:
     VSLArgList()
@@ -74,10 +66,12 @@ public:
 	return _list;
     }
 
+#if 0
     operator ListBox *() const
     {
 	return list();
     }
+#endif
 };
 
 #endif // _DDD_VSLArgList_h
