@@ -39,6 +39,7 @@
 #include <iostream>
 #include "strclass.h"
 #include "bool.h"
+#include "mutable.h"
 #include "VSLNode.h"
 #include "TypeInfo.h"
 #include "assert.h"
@@ -53,7 +54,7 @@ public:
 private:
     VSLNode *_expr;             // Expr (definition body)
     VSLNode *_node_pattern;     // Pattern
-    Box *_box_pattern;          // Compiled pattern
+    mutable Box *_box_pattern;          // Compiled pattern
 
     unsigned _nargs;            // Number of args
     bool _straight;		// Flag: Can we use arg list `as is'?
@@ -67,14 +68,14 @@ private:
 
     string args() const;        // Create argument list
 
-    bool being_compiled;	// Protect against recursive compilePattern()
+    mutable bool being_compiled;	// Protect against recursive compilePattern()
 
 public:
     VSLDefList *deflist;        // Parent
 
     // Constructor
     VSLDef(VSLDefList* l, VSLNode *pattern, VSLNode *e = 0,
-	   string filename = "builtin", int lineno = 0);
+	   const string& filename = "builtin", int lineno = 0);
 
 private:
     // Copy constructor
@@ -108,7 +109,7 @@ public:
     string f_name() const;        // external name (including args)
     string longname() const;      // external name (including args and loc)
 
-    string filename() const     { return _filename; }
+    const string& filename() const     { return _filename; }
     int lineno() const          { return _lineno; }
 
     // Evaluate
@@ -125,8 +126,8 @@ public:
     void uncompilePattern() const
     {
 	if (_box_pattern) 
-	    ((VSLDef *)this)->_box_pattern->unlink();
-	((VSLDef *)this)->_box_pattern = 0;
+	    MUTABLE_THIS(VSLDef *)->_box_pattern->unlink();
+	MUTABLE_THIS(VSLDef *)->_box_pattern = 0;
     }
 
     // Resolve names
