@@ -62,6 +62,9 @@
 /* Define if your C++ compiler supports new C++ casts, such as const_cast */
 #undef HAVE_NEW_CASTS
 
+/* Define if your C++ compiler supports __attribute__ ((noreturn)). */
+#undef HAVE_ATTRIBUTE_NORETURN
+
 /* Define if your C++ compiler supports exception handling. */
 #undef HAVE_EXCEPTIONS
 
@@ -81,16 +84,16 @@
 #undef HAVE_PTRACE_DUMPCORE
 
 /* Define if your C++ library has an ostringstream::frozen() function. */
-#undef HAVE_FROZEN_OSTRINGSTREAM
+/* Phased out: #undef HAVE_FROZEN_OSTRSTREAM */
 
 /* Define if your C++ library has an ostringstreambuf::frozen() function. */
-#undef HAVE_FROZEN_OSTRINGSTREAMBUF
+/* Phased out: #undef HAVE_FROZEN_OSTRSTREAMBUF */
 
 /* Define if your C++ library has an ostringstream::freeze() function. */
-#undef HAVE_FREEZE_OSTRINGSTREAM
+/* Phased out: #undef HAVE_FREEZE_OSTRSTREAM */
 
 /* Define if your C++ library has an ostringstreambuf::freeze() function. */
-#undef HAVE_FREEZE_OSTRINGSTREAMBUF
+/* Phased out: #undef HAVE_FREEZE_OSTRSTREAMBUF */
 
 /* Define if the ios::iostate type is defined or declared in <iostream.h>. */
 #undef HAVE_IOSTATE
@@ -129,9 +132,6 @@
 /* Define if the Motif library defines Xm21InstallImage */
 #undef HAVE_XM21INSTALLIMAGE
 
-/* Define if your C++ compiler supports named return values. */
-#undef HAVE_NAMED_RETURN_VALUES
-
 /* Define if PATH_MAX is defined or declared in <limits.h>. */
 #undef HAVE_PATH_MAX
 
@@ -156,7 +156,7 @@
 
 /* Define if ostringstream::pcount() is increased by 1 after accessing the
    string via ostringstream::str(), as in the SGI C++ I/O library. */
-#undef OSTRINGSTREAM_PCOUNT_BROKEN
+/* Phased out: #undef OSTRSTREAM_PCOUNT_BROKEN */
 
 /* Define to the signal handler type accepted by signal(). 
    See the signal man page and the decl in <signal.h> for the exact type.
@@ -360,7 +360,7 @@
 /* Define if strftime is declared in time.h. */
 #undef HAVE_STRFTIME_DECL
 
-/* Define if strsignal is declared in string.h. */
+/* Define if strsignal is declared in string.h unistd.h. */
 #undef HAVE_STRSIGNAL_DECL
 
 /* Define if strtod is declared in stdlib.h. */
