@@ -49,7 +49,7 @@ ICE_CHECK_DECL(srandom, stdlib.h math.h)
 ICE_CHECK_DECL(stat, sys/stat.h)
 ICE_CHECK_DECL(strerror, string.h)
 ICE_CHECK_DECL(strftime, time.h)
-ICE_CHECK_DECL(strsignal, string.h)
+ICE_CHECK_DECL(strsignal, string.h unistd.h)
 ICE_CHECK_DECL(strtod, stdlib.h)
 ICE_CHECK_DECL(strtol, stdlib.h)
 ICE_CHECK_DECL(strtoul, stdlib.h)
