@@ -1,4 +1,4 @@
-// $Id: assert.h,v 1.10 2000/05/29 14:07:25 andreas Exp $
+// $Id$
 // own assert() macros
 // built on libg++-assert.h and making sure top-level abort() is called
 
@@ -42,7 +42,7 @@
 #endif
 
 #include <stdlib.h>		// abort()
-#include <iostream.h>
+#include <iostream>
 
 #undef assert
 #undef _assert_fn
@@ -55,7 +55,7 @@
 #endif // !HAVE_PRETTY_FUNCTION
 
 #define assert(ex) \
-((ex) ? 1 : (cerr << _assert_fn << "\n" << __FILE__ << ":" << __LINE__ \
+((ex) ? 1 : (std::cerr << _assert_fn << "\n" << __FILE__ << ":" << __LINE__ \
 	          << ": assertion `" #ex "' failed\n", \
 	          ::abort(), 0))
 
