@@ -92,31 +92,61 @@ inline MString tt(const string& text)
     return MString(text, CHARSET_TT);
 }
 
+inline MString tt(const char *text) 
+{
+    return MString(text, CHARSET_TT);
+}
+
 inline MString tb(const string& text) 
 {
     return MString(text, CHARSET_TB);
 }
 
+inline MString tb(const char *text) 
+{
+    return MString(text, CHARSET_TB);
+}
+
 inline MString rm(const string& text) 
 {
     return MString(text, CHARSET_RM);
 }
 
+inline MString rm(const char *text) 
+{
+    return MString(text, CHARSET_RM);
+}
+
 inline MString sl(const string& text) 
 {
     return MString(text, CHARSET_SL);
 }
 
+inline MString sl(const char *text) 
+{
+    return MString(text, CHARSET_SL);
+}
+
 inline MString bf(const string& text) 
 {
     return MString(text, CHARSET_BF);
 }
 
+inline MString bf(const char *text) 
+{
+    return MString(text, CHARSET_BF);
+}
+
 inline MString bs(const string& text) 
 {
     return MString(text, CHARSET_BS);
 }
 
+inline MString bs(const char *text) 
+{
+    return MString(text, CHARSET_BS);
+}
+
 
 // Newline function
 #if XmVERSION == 1 && XmREVISION <= 1
