@@ -1,4 +1,4 @@
-// $Id: file.h,v 1.18 2000/01/12 17:38:21 andreas Exp $ -*- C++ -*-
+// $Id$ -*- C++ -*-
 // DDD file handling
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
@@ -53,7 +53,7 @@ void get_gdb_sources(StringArray& sources_list);
 void update_sources();
 
 // When entering `cd', change path in file selection boxes
-extern void process_cd(string pwd);
+extern void process_cd(const string& pwd);
 
 // Get the file name from the file selection box W
 string get_file(Widget w, XtPointer, XtPointer call_data);
