@@ -63,8 +63,8 @@ void getItemNumbers(Widget selectionList, IntArray& arr);
 // NOTIFY:          Whether callbacks should be invoked
 //
 void setLabelList (Widget  selectionList,
-		   string  label_list[],
-		   bool    selected[],
+		   const string  label_list[],
+		   const bool selected[],
 		   int     list_length,
 		   bool    highlight_title,
 		   bool    notify);
@@ -72,7 +72,7 @@ void setLabelList (Widget  selectionList,
 // Replace all elements in SELECTIONLIST with the corresponding
 // entries in LABEL_LIST (i.e. with the same leading number).
 void updateLabelList (Widget  selectionList,
-		      string  label_list[],
+		      const string  label_list[],
 		      int     list_length);
 
 // The default list charset
@@ -86,7 +86,7 @@ void ListSetAndSelectPos(Widget list, int pos);
 
 // Create an array of XmStrings from the list LABEL_LIST of length
 // LIST_LENGTH.  If HIGHLIGHT_TITLE is set, let the first line be bold.
-XmStringTable makeXmStringTable(string label_list[],
+XmStringTable makeXmStringTable(const string label_list[],
 				int list_length, 
 				bool highlight_title = false);
 
