@@ -22,8 +22,8 @@ Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // Differences to GNU String class:
 // - class name is `string' instead of `String'
 // - string length is `unsigned int' instead of `short'
-// - extra constructor string::string(ostrstream&)
-// - extra assignment string::operator=(ostrstream&)
+// - extra constructor string::string(std::ostringstream&)
+// - extra assignment string::operator=(std::ostringstream&)
 // - output to stream issues *all* characters, including '\0'
 // - extra functions for `char *' provided (besides `const char *')
 // - `cat' with 4 arguments is not supported
@@ -417,6 +417,7 @@ Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #include "bool.h"
 #include "assert.h"
 #include "casts.h"
+#include "attribute.h"
 
 #ifndef STRING_CHECK_CONSUME
 #define STRING_CHECK_CONSUME 0
@@ -570,15 +571,8 @@ protected:
 
 private:
     // Don't get constructed or assigned from int
-    string(int) : rep(0)
-#if STRING_CHECK_CONSUME
-	, consume(false)
-#endif
-    { 
-	error("init from int");
-    }
-    string& operator = (int)             { error("int assign"); return *this; }
-
+    string(int);
+    string& operator = (int);
 public:
     // Constructors and assignment
     string();
@@ -623,6 +617,7 @@ public:
     // Concatenate first 2 args, store result in last arg
     friend inline void cat(const string&, const string&, string&);
     friend inline void cat(const string&, const subString&, string&);
+    friend inline void cat(const string&, const constSubString&, string&);
     friend inline void cat(const string&, const char*, string&);
     friend inline void cat(const string&, char*, string&);
     friend inline void cat(const string&, char, string&);
@@ -824,7 +819,7 @@ public:
 				int startpos = 0);
     friend string common_suffix(const string& x, const string& y, 
 				int startpos = -1);
-    // friend string replicate(char c, int n);
+    friend string replicate(char c, int n);
     friend string replicate(const string& y, int n);
     friend string join(const string *src, int n, const string& sep);
 
@@ -865,13 +860,6 @@ public:
     char lastchar() const;
 
     // Conversion
-#if 0
-    // TODO remove
- private:
-    operator const char*() const;
-    operator char*() const;
- public:
-#endif
     const char* chars() const;
 
 
@@ -894,7 +882,7 @@ public:
     // Report current allocation (not length!)
     int allocation() const;
 
-    void error(const char* msg) const;
+    void error(const char* msg) const ATTRIBUTE_NORETURN;
 
     bool OK() const;
 };
@@ -1152,14 +1140,30 @@ inline string& string::operator = (std::ostringstream& os)
 {
     assert(!consuming());
 
+    const std::string str( os.str() );
+    rep = string_Salloc(rep, str.c_str(), str.length(), str.length());
+
+    return *this;
+}
+
+#if 0
+// Phased out
+#include <strstream>
+
+inline string& string::operator = (std::ostrstream& os)
+{
+    assert(!consuming());
+
     // No need to freeze the stream, since the string is copied right away
 #if HAVE_FROZEN_OSTRSTREAMBUF
     const int frozen = os.rdbuf()->frozen();
 #elif HAVE_FROZEN_OSTRSTREAM
     const int frozen = os.frozen();
+#else
+    const int frozen = 0; // Pretty optimistic ...
 #endif
 
-    const char *str = os.str().c_str();
+    const char *str = os.str();
 
 #if OSTRSTREAM_PCOUNT_BROKEN
     // In the SGI C++ I/O library, accessing os.str() *increases*
@@ -1168,7 +1172,7 @@ inline string& string::operator = (std::ostringstream& os)
     // this will cause trouble when os is assigned the next time.
     rep = string_Salloc(rep, str, os.pcount() - 1, os.pcount() - 1);
 #else
-    rep = string_Salloc(rep, str, os.str().length(), os.str().length());
+    rep = string_Salloc(rep, str, os.pcount(), os.pcount());
 #endif
 
 #if HAVE_FREEZE_OSTRSTREAMBUF
@@ -1179,6 +1183,7 @@ inline string& string::operator = (std::ostringstream& os)
     
     return *this;
 }
+#endif
 
 inline string::string(std::ostringstream& os)
     : rep(&_nilstrRep)
@@ -1231,6 +1236,12 @@ inline void cat(const string& x, const subString& y, string& r)
     r.rep = string_Scat(r.rep, x.chars(), x.length(), y.chars(), y.length());
 }
 
+inline void cat(const string& x, const constSubString& y, string& r)
+{
+  assert(!r.consuming());
+  r.rep = string_Scat(r.rep, x.chars(), x.length(), y.chars(), y.length());
+}
+
 inline void cat(const string& x, const char* y, string& r)
 {
     assert(!r.consuming());
@@ -1402,109 +1413,6 @@ inline string& string:: operator +=(char y)
 }
 
 // Constructive concatenation
-#if HAVE_NAMED_RETURN_VALUES
-
-inline string operator + (const string& x, const string& y) return r;
-{
-    cat(x, y, r);
-}
-
-inline string operator + (const string& x, const subString& y) return r;
-{
-    cat(x, y, r);
-}
-
-inline string operator + (const string& x, const char* y) return r;
-{
-    cat(x, y, r);
-}
-
-inline string operator + (const string& x, char* y) return r;
-{
-    cat(x, y, r);
-}
-
-inline string operator + (const string& x, char y) return r;
-{
-    cat(x, y, r);
-}
-
-inline string operator + (const subString& x, const string& y) return r;
-{
-    cat(x, y, r);
-}
-
-inline string operator + (const subString& x, const subString& y) return r;
-{
-    cat(x, y, r);
-}
-
-inline string operator + (const subString& x, const char* y) return r;
-{
-    cat(x, y, r);
-}
-
-inline string operator + (const subString& x, char* y) return r;
-{
-    cat(x, y, r);
-}
-
-inline string operator + (const subString& x, char y) return r;
-{
-    cat(x, y, r);
-}
-
-inline string operator + (const char* x, const string& y) return r;
-{
-    cat(x, y, r);
-}
-
-inline string operator + (const char* x, const subString& y) return r;
-{
-    cat(x, y, r);
-}
-
-inline string operator + (char* x, const string& y) return r;
-{
-    cat(x, y, r);
-}
-
-inline string operator + (char* x, const subString& y) return r;
-{
-    cat(x, y, r);
-}
-
-inline string operator + (char x, const string& y) return r;
-{
-    cat(x, y, r);
-}
-
-inline string operator + (char x, const subString& y) return r;
-{
-    cat(x, y, r);
-}
-
-inline string reverse(const string& x) return r;
-{
-    r.rep = string_Sreverse(x.rep, r.rep);
-}
-
-inline string upcase(const string& x) return r;
-{
-    r.rep = string_Supcase(x.rep, r.rep);
-}
-
-inline string downcase(const string& x) return r;
-{
-    r.rep = string_Sdowncase(x.rep, r.rep);
-}
-
-inline string capitalize(const string& x) return r;
-{
-    r.rep = string_Scapitalize(x.rep, r.rep);
-}
-
-#else /* ! defined(NAMED_RETURN_VALUES) */
 
 inline string operator + (const string& x, const string& y)
 {
@@ -1606,8 +1514,6 @@ inline string capitalize(const string& x)
     string r; r.rep = string_Scapitalize(x.rep, r.rep); return r;
 }
 
-#endif /* ! defined(NAMED_RETURN_VALUES) */
-
 // prepend
 
 inline string& string::prepend(const string& y)
